@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.contactcollector.internal;
 
+import static com.openexchange.mail.mime.QuotedInternetAddress.toIDN;
 import java.io.UnsupportedEncodingException;
 import java.text.MessageFormat;
 import java.util.Collections;
@@ -90,6 +91,7 @@ import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.oxfolder.OXFolderAccess;
+import com.openexchange.tools.session.ServerSessionAdapter;
 import com.openexchange.user.UserService;
 import com.openexchange.userconf.UserConfigurationService;
 
@@ -231,11 +233,17 @@ public class Memorizer implements Runnable {
 
         final int retval;
         if (null == foundContact) {
-            final OCLPermission perm = new OXFolderAccess(ctx).getFolderPermission(getFolderId(), session.getUserId(), userConfig);
-            if (perm.canCreateObjects()) {
-                contact.setUseCount(1);
-                contactInterface.insertContactObject(contact);
-                retval = contact.getObjectID();
+            final OXFolderAccess folderAccess = new OXFolderAccess(ctx);
+            final int folderId = getFolderId();
+            if (folderAccess.exists(folderId)) {
+                final OCLPermission perm = folderAccess.getFolderPermission(folderId, session.getUserId(), userConfig);
+                if (perm.canCreateObjects()) {
+                    contact.setUseCount(1);
+                    contactInterface.insertContactObject(contact);
+                    retval = contact.getObjectID();
+                } else {
+                    retval = -1;
+                }
             } else {
                 retval = -1;
             }
@@ -292,17 +300,21 @@ public class Memorizer implements Runnable {
 
     private boolean isEnabled() {
         Boolean enabled = null;
+        Boolean enabledRight = null;
         try {
             enabled = ServerUserSetting.isContactCollectionEnabled(session.getContextId(), session.getUserId());
+            enabledRight = new ServerSessionAdapter(session).getUserConfiguration().isCollectEmailAddresses();
         } catch (final SettingException e) {
             LOG.error(e.getMessage(), e);
+        } catch (final ContextException e) {
+            LOG.error(e.getMessage(), e);
         }
-        return enabled != null && enabled.booleanValue();
+        return enabled != null && enabledRight != null && enabled.booleanValue() && enabled.booleanValue();
     }
 
     private Contact transformInternetAddress(final InternetAddress address) throws ParseException, UnsupportedEncodingException {
         final Contact retval = new Contact();
-        final String addr = decodeMultiEncodedValue(address.getAddress());
+        final String addr = decodeMultiEncodedValue(toIDN(address.getAddress()));
         retval.setEmail1(addr);
         final String displayName;
         if (address.getPersonal() != null && !"".equals(address.getPersonal().trim())) {
